@@ -13,7 +13,7 @@ BEGIN {
 
 use Graph::AdjacencyMap qw(:flags :fields);
 
-our $VERSION = '0.9710';
+our $VERSION = '0.9711';
 
 require 5.006; # Weak references are absolutely required.
 
@@ -1764,9 +1764,21 @@ sub as_hashes {
 sub ingest {
     my ($g, $g2) = @_;
     for my $v ($g2->vertices) {
-        $g->set_vertex_attributes($v, $g2->get_vertex_attributes($v));
-        $g->set_edge_attributes(@$_, $g2->get_edge_attributes(@$_))
-            for $g2->edges_from($v);
+        if ($g->is_multivertexed) {
+            $g->set_vertex_attributes_by_id($v, $_, $g2->get_vertex_attributes_by_id($v, $_))
+                for $g2->get_multivertex_ids($v);
+        } else {
+            $g->set_vertex_attributes($v, $g2->get_vertex_attributes($v));
+        }
+        if ($g->is_multiedged) {
+            for my $e ($g2->edges_from($v)) {
+                $g->set_edge_attributes_by_id(@$e, $_, $g2->get_edge_attributes_by_id(@$e, $_))
+                    for $g2->get_multiedge_ids(@$e);
+            }
+        } else {
+            $g->set_edge_attributes(@$_, $g2->get_edge_attributes(@$_))
+                for $g2->edges_from($v);
+        }
     }
     $g;
 }
